import { aws_ec2 as ec2, aws_networkfirewall as firewall } from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Propertys of a Network Firewall
 */
export interface NetworkFirewallProps {
    /**
     * the the vpc where the Network firewall is placed
     */
    readonly vpc: ec2.Vpc;
    /**
     * the subnetGroup where the firewall will be created.
     */
    readonly subnetGroup: string;
    /**
     * the name that will be given to the firewall
     */
    readonly firewallName: string;
    /**
     * the firewalls policy
     */
    readonly firewallPolicy: firewall.CfnFirewallPolicy;
}
/**
 * Creates Network Firewalls
 */
export declare class NetworkFirewall extends constructs.Construct {
    /**
     * Gateway Endpoints for the Firewalls
     */
    readonly endPointIds: string[];
    /**
     * Arn of the firewall
     */
    readonly firewallArn: string;
    /**
     * Firewall ID
     */
    readonly firewallId: string;
    /**
     *
     * @param scope Scope
     * @param id id
     * @param props props
     */
    constructor(scope: constructs.Construct, id: string, props: NetworkFirewallProps);
}
